pub enum UnexportError {
MustExportDefinition,
}Expand description
Represents an error that can occur when unexporting a node in a composition graph.
Variants
MustExportDefinition
The node cannot be unexported as it is a type definition.